# TopasOpt

![](docsrc/_resources/interrogate_badge.svg) ![](docsrc/_resources/coverage.svg)


This code provides a framework for performing optimisation on monte carlo radiation transport 
simulations using [TOPAS](https://www.google.com/search?channel=fs&client=ubuntu&q=topas+MC).

## Install and Requirements

To install: ```pip install TopasOpt```
If you need help setting up a python environment see [here](https://acrf-image-x-institute.github.io/TopasOpt/EnvironmentSetup.html)

- This code will only run on linux (as will topas) (I don't have a mac to check it on but I think it will work)
- You require a working installation of [topas](https://topas.readthedocs.io/en/latest/getting-started/intro.html) to run the code.
- python3.8 or greater is required.

## Usage and Documentation

Detailed documentation is provided [here](https://acrf-image-x-institute.github.io/TopasOpt/index.html)
The source code for the [worked examples](https://acrf-image-x-institute.github.io/TopasOpt/worked_examples.html) is inside the examples folder.

## Directory Structure

- **TopasOpt:** source code
- **examples:** as the name implies!
- **docs:** html documentation created from docsrc using sphinx
- **docsrc:** markdown/rst documentation.
- **tests:** tests which are run on push







